define(['dart_sdk', 'packages/source_span/lib__source_span', 'packages/transformer_utils/lib__transformer_utils', 'packages/test/lib__test', 'packages/matcher/lib__shared_0', 'packages/analyzer/lib__analyzer'], function(dart_sdk, lib__source_span, lib__transformer_utils, lib__test, lib__shared_0, lib__analyzer) {
  'use strict';
  const core = dart_sdk.core;
  const _interceptors = dart_sdk._interceptors;
  const dart = dart_sdk.dart;
  const dartx = dart_sdk.dartx;
  const src__file = lib__source_span.src__file;
  const src__transformed_source_file = lib__transformer_utils.src__transformed_source_file;
  const test = lib__test.test;
  const src__frontend__expect = lib__test.src__frontend__expect;
  const src__frontend__throws_matcher = lib__test.src__frontend__throws_matcher;
  const src__string_matchers = lib__shared_0.src__string_matchers;
  const src__core_matchers = lib__shared_0.src__core_matchers;
  const analyzer = lib__analyzer.analyzer;
  const _root = Object.create(null);
  const unit__transformed_source_file_test = Object.create(_root);
  const $single = dartx.single;
  const $allMatches = dartx.allMatches;
  const $add = dartx.add;
  const $indexOf = dartx.indexOf;
  let VoidToNull = () => (VoidToNull = dart.constFn(dart.fnType(core.Null, [])))();
  let VoidToString = () => (VoidToString = dart.constFn(dart.fnType(core.String, [])))();
  let StringToNull = () => (StringToNull = dart.constFn(dart.fnType(core.Null, [core.String])))();
  let JSArrayOfString = () => (JSArrayOfString = dart.constFn(_interceptors.JSArray$(core.String)))();
  unit__transformed_source_file_test.main = function() {
    test.group('TransformedSourceFile', dart.fn(() => {
      let testSourceFile = null;
      let transformedFile = null;
      test.setUp(dart.fn(() => {
        testSourceFile = new src__file.SourceFile.fromString('0123456789', {url: 'test_source_file.dart'});
        transformedFile = new src__transformed_source_file.TransformedSourceFile.new(testSourceFile);
      }, VoidToNull()));
      test.group('replace()', dart.fn(() => {
        test.test('replaces a span of text and outputs the result', dart.fn(() => {
          transformedFile.replace(testSourceFile.span(3, 8), '{replaced}');
          src__frontend__expect.expect(transformedFile.getTransformedText(), '012{replaced}89');
        }, VoidToNull()));
        test.test('replaces multiple spans of text and outputs the result', dart.fn(() => {
          transformedFile.replace(testSourceFile.span(1, 2), '{replaced 1}');
          transformedFile.replace(testSourceFile.span(6, 9), '{replaced 2}');
          transformedFile.replace(testSourceFile.span(4, 6), '{replaced 3}');
          src__frontend__expect.expect(transformedFile.getTransformedText(), '0{replaced 1}23{replaced 3}{replaced 2}9');
        }, VoidToNull()));
        test.test('inserts text and outputs the result', dart.fn(() => {
          transformedFile.insert(testSourceFile.location(4), '{inserted}');
          src__frontend__expect.expect(transformedFile.getTransformedText(), '0123{inserted}456789');
        }, VoidToNull()));
      }, VoidToNull()));
      test.group('insert()', dart.fn(() => {
        test.test('inserts multiple pieces of text and outputs the result', dart.fn(() => {
          transformedFile.insert(testSourceFile.location(1), '{inserted 1}');
          transformedFile.insert(testSourceFile.location(6), '{inserted 2}');
          transformedFile.insert(testSourceFile.location(4), '{inserted 3}');
          src__frontend__expect.expect(transformedFile.getTransformedText(), '0{inserted 1}123{inserted 3}45{inserted 2}6789');
        }, VoidToNull()));
        test.test('throws if sections of replaced text overlap each other', dart.fn(() => {
          transformedFile.replace(testSourceFile.span(1, 3), '{replaced 1}');
          transformedFile.replace(testSourceFile.span(0, 2), '{replaced 2}');
          src__frontend__expect.expect(dart.fn(() => transformedFile.getTransformedText(), VoidToString()), src__frontend__throws_matcher.throwsA(src__string_matchers.startsWith('Overlapping replacement')));
        }, VoidToNull()));
      }, VoidToNull()));
      test.group('remove()', dart.fn(() => {
        let text = 'line 0\nline 1\nline 2\nline 3\nline 4';
        let lines1Through3Span = null;
        test.setUp(dart.fn(() => {
          testSourceFile = new src__file.SourceFile.fromString(text);
          transformedFile = new src__transformed_source_file.TransformedSourceFile.new(testSourceFile);
          let lines1Through3 = '\nline 1\nline 2\nline 3'[$allMatches](text)[$single];
          lines1Through3Span = testSourceFile.span(lines1Through3.start, lines1Through3.end);
        }, VoidToNull()));
        test.test('removes spans of text, removing newlines by default', dart.fn(() => {
          transformedFile.remove(lines1Through3Span);
          src__frontend__expect.expect(transformedFile.getTransformedText(), 'line 0\nline 4');
        }, VoidToNull()));
        test.test('removes spans of text, preserving newlines when specified', dart.fn(() => {
          transformedFile.remove(lines1Through3Span, {preserveNewlines: true});
          src__frontend__expect.expect(transformedFile.getTransformedText(), 'line 0\n\n\n\nline 4');
        }, VoidToNull()));
      }, VoidToNull()));
      test.group('`isModified`', dart.fn(() => {
        test.test('is true when a replacement has been made', dart.fn(() => {
          transformedFile.replace(testSourceFile.span(3, 8), '{replaced}');
          src__frontend__expect.expect(transformedFile.isModified, src__core_matchers.isTrue);
        }, VoidToNull()));
        test.test('is true when an insertion has been made', dart.fn(() => {
          transformedFile.insert(testSourceFile.location(3), '{replaced}');
          src__frontend__expect.expect(transformedFile.isModified, src__core_matchers.isTrue);
        }, VoidToNull()));
        test.test('is false for a pristine TransformedSourceFile', dart.fn(() => {
          src__frontend__expect.expect(transformedFile.isModified, src__core_matchers.isFalse);
        }, VoidToNull()));
      }, VoidToNull()));
      test.group('iterateReplacements()', dart.fn(() => {
        test.test('iterates through the replacements using the specified callbacks', dart.fn(() => {
          let unmodifieds = [];
          let additions = [];
          let removals = [];
          let all = [];
          transformedFile.remove(testSourceFile.span(2, 3));
          transformedFile.remove(testSourceFile.span(8, 9));
          transformedFile.insert(testSourceFile.location(1), '{inserted 1}');
          transformedFile.insert(testSourceFile.location(7), '{inserted 2}');
          transformedFile.replace(testSourceFile.span(5, 7), '{replaced 1}');
          transformedFile.replace(testSourceFile.span(0, 1), '{replaced 2}');
          transformedFile.iterateReplacements({onUnmodified: dart.fn(text => {
              unmodifieds[$add](text);
              all[$add](text);
            }, StringToNull()), onRemoval: dart.fn(text => {
              removals[$add](text);
              all[$add](text);
            }, StringToNull()), onAddition: dart.fn(text => {
              additions[$add](text);
              all[$add](text);
            }, StringToNull())});
          src__frontend__expect.expect(unmodifieds, src__core_matchers.equals(JSArrayOfString().of(['1', '34', '7', '9'])));
          src__frontend__expect.expect(additions, src__core_matchers.equals(JSArrayOfString().of(['{replaced 2}', '{inserted 1}', '{replaced 1}', '{inserted 2}'])));
          src__frontend__expect.expect(removals, src__core_matchers.equals(JSArrayOfString().of(['0', '2', '56', '8'])));
          src__frontend__expect.expect(all, src__core_matchers.equals(JSArrayOfString().of(['0', '{replaced 2}', '{inserted 1}', '1', '2', '34', '56', '{replaced 1}', '{inserted 2}', '7', '8', '9'])), {reason: 'should have called all parts in the right order'});
        }, VoidToNull()));
      }, VoidToNull()));
      test.group('getHtmlDiff()', dart.fn(() => {
        test.test('returns an HTML page containing the diff of the modified file', dart.fn(() => {
          transformedFile.remove(testSourceFile.span(2, 3));
          transformedFile.remove(testSourceFile.span(8, 9));
          transformedFile.insert(testSourceFile.location(1), '{inserted 1}');
          transformedFile.insert(testSourceFile.location(7), '{inserted 2}');
          transformedFile.replace(testSourceFile.span(5, 7), '{replaced 1}');
          transformedFile.replace(testSourceFile.span(0, 1), '{replaced 2}');
          let html = transformedFile.getHtmlDiff();
          src__frontend__expect.expect(html, src__string_matchers.matches(core.RegExp.new('^\\s*<\\!DOCTYPE html>\\s*<html>')));
          src__frontend__expect.expect(html, src__core_matchers.contains('<title>Transformer Diff - ' + 'test_source_file.dart' + '</title>'));
          src__frontend__expect.expect(html, src__core_matchers.contains('<pre>' + '<span class="diff-removal">0</span>' + '<span class="diff-addition">{replaced 2}</span>' + '<span class="diff-addition">{inserted 1}</span>' + '<span class="diff-unmodified">1</span>' + '<span class="diff-removal">2</span>' + '<span class="diff-unmodified">34</span>' + '<span class="diff-removal">56</span>' + '<span class="diff-addition">{replaced 1}</span>' + '<span class="diff-addition">{inserted 2}</span>' + '<span class="diff-unmodified">7</span>' + '<span class="diff-removal">8</span>' + '<span class="diff-unmodified">9</span>' + '</pre>'));
          src__frontend__expect.expect(html, src__string_matchers.matches(core.RegExp.new('</html>\\s*$')));
        }, VoidToNull()));
      }, VoidToNull()));
    }, VoidToNull()));
    test.group('getSpan()', dart.fn(() => {
      let source = '\n' + '/// Doc comment\n' + '@Annotation\n' + 'class Node {}\n';
      let sourceFile = null;
      let node = null;
      test.setUp(dart.fn(() => {
        sourceFile = new src__file.SourceFile.fromString(source);
        node = analyzer.parseCompilationUnit(source).declarations.single;
      }, VoidToNull()));
      test.test('returns a SourceSpan for a node, skipping its doc comments and meta by default', dart.fn(() => {
        let span = src__transformed_source_file.getSpan(sourceFile, node);
        src__frontend__expect.expect(span.start.offset, src__core_matchers.equals(source[$indexOf]('class')));
        src__frontend__expect.expect(span.end.offset, src__core_matchers.equals(source[$indexOf]('}') + 1));
      }, VoidToNull()));
      test.test('returns a SourceSpan for a node, including its doc comments and meta', dart.fn(() => {
        let span = src__transformed_source_file.getSpan(sourceFile, node, {skipCommentAndMetadata: false});
        src__frontend__expect.expect(span.start.offset, src__core_matchers.equals(source[$indexOf]('///')));
        src__frontend__expect.expect(span.end.offset, src__core_matchers.equals(source[$indexOf]('}') + 1));
      }, VoidToNull()));
    }, VoidToNull()));
  };
  dart.trackLibraries("test/test__unit__transformed_source_file_test", {
    "unit/transformed_source_file_test.dart": unit__transformed_source_file_test
  }, '{"version":3,"sourceRoot":"","sources":["unit/transformed_source_file_test.dart"],"names":[],"mappings":";;;;;;;;;;;;;;;;;;;;;;;;;AAuBE,cAAK,CAAC,yBAAyB;AAC7B,UAAW;AACX,UAAsB;AAEtB,gBAAK,CAAC;AACJ,sBAAc,GACV,IAAI,+BAAqB,CAAC,oBAAmB;AACjD,uBAAe,GAAG,IAAI,sDAAqB,CAAC,cAAc;;AAG5D,gBAAK,CAAC,aAAa;AACjB,iBAAI,CAAC,kDAAkD;AACrD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,sCAAM,CAAC,eAAe,mBAAmB,IAAI;;AAG/C,iBAAI,CAAC,0DAA0D;AAC7D,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,sCAAM,CAAC,eAAe,mBAAmB,IACrC;;AAGN,iBAAI,CAAC,uCAAuC;AAC1C,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,sCAAM,CAAC,eAAe,mBAAmB,IAAI;;;AAIjD,gBAAK,CAAC,YAAY;AAChB,iBAAI,CAAC,0DAA0D;AAC7D,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,sCAAM,CAAC,eAAe,mBAAmB,IACrC;;AAGN,iBAAI,CAAC,0DAA0D;AAC7D,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,sCAAM,CAAC,cAAM,eAAe,mBAAmB,qBAC3C,qCAAO,CAAC,+BAAU,CAAC;;;AAI3B,gBAAK,CAAC,YAAY;AAChB,YAAa,OAAO;AACpB,YAAW;AAEX,kBAAK,CAAC;AACJ,wBAAc,GAAG,IAAI,+BAAqB,CAAC,IAAI;AAC/C,yBAAe,GAAG,IAAI,sDAAqB,CAAC,cAAc;AAE1D,cAAI,iBAAiB,uCAAqC,CAAC,IAAI,UAAQ;AACvE,4BAAkB,GACd,cAAc,KAAK,CAAC,cAAc,MAAM,EAAE,cAAc,IAAI;;AAGlE,iBAAI,CAAC,uDAAuD;AAC1D,yBAAe,OAAO,CAAC,kBAAkB;AACzC,sCAAM,CAAC,eAAe,mBAAmB,IAAI;;AAG/C,iBAAI,CAAC,6DAA6D;AAChE,yBAAe,OAAO,CAAC,kBAAkB,qBAAoB;AAC7D,sCAAM,CAAC,eAAe,mBAAmB,IAAI;;;AAIjD,gBAAK,CAAC,gBAAgB;AACpB,iBAAI,CAAC,4CAA4C;AAC/C,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,sCAAM,CAAC,eAAe,WAAW,EAAE,yBAAM;;AAG3C,iBAAI,CAAC,2CAA2C;AAC9C,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,sCAAM,CAAC,eAAe,WAAW,EAAE,yBAAM;;AAG3C,iBAAI,CAAC,iDAAiD;AACpD,sCAAM,CAAC,eAAe,WAAW,EAAE,0BAAO;;;AAI9C,gBAAK,CAAC,yBAAyB;AAC7B,iBAAI,CAAC,mEACD;AACF,cAAI,cAAc;AAClB,cAAI,YAAY;AAChB,cAAI,WAAW;AAEf,cAAI,MAAM;AAEV,yBAAe,OAAO,CAAC,cAAc,KAAK,CAAC,GAAG;AAC9C,yBAAe,OAAO,CAAC,cAAc,KAAK,CAAC,GAAG;AAC9C,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AAEnD,yBAAe,oBAAoB,gBAAe,QAAC,IAAI;AACrD,yBAAW,MAAI,CAAC,IAAI;AACpB,iBAAG,MAAI,CAAC,IAAI;2CACA,QAAC,IAAI;AACjB,sBAAQ,MAAI,CAAC,IAAI;AACjB,iBAAG,MAAI,CAAC,IAAI;4CACC,QAAC,IAAI;AAClB,uBAAS,MAAI,CAAC,IAAI;AAClB,iBAAG,MAAI,CAAC,IAAI;;AAGd,sCAAM,CAAC,WAAW,EAAE,yBAAM,CAAC,sBAAC,KAAK,MAAM,KAAK;AAC5C,sCAAM,CACF,SAAS,EACT,yBAAM,CAAC,sBACL,gBACA,gBACA,gBACA;AAEN,sCAAM,CAAC,QAAQ,EAAE,yBAAM,CAAC,sBAAC,KAAK,KAAK,MAAM;AAEzC,sCAAM,CACF,GAAG,EACH,yBAAM,CAAC,sBACL,KACA,gBACA,gBACA,KACA,KACA,MACA,MACA,gBACA,gBACA,KACA,KACA,iBAEM;;;AAIhB,gBAAK,CAAC,iBAAiB;AACrB,iBAAI,CAAC,iEAAiE;AACpE,yBAAe,OAAO,CAAC,cAAc,KAAK,CAAC,GAAG;AAC9C,yBAAe,OAAO,CAAC,cAAc,KAAK,CAAC,GAAG;AAC9C,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,OAAO,CAAC,cAAc,SAAS,CAAC,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AACnD,yBAAe,QAAQ,CAAC,cAAc,KAAK,CAAC,GAAG,IAAI;AAEnD,cAAI,OAAO,eAAe,YAAY;AAEtC,sCAAM,CAAC,IAAI,EAAE,4BAAO,CAAC,AAAI,eAAM,CAAC;AAChC,sCAAM,CACF,IAAI,EACJ,2BAAQ,CAAC,+BACL,0BACA;AACR,sCAAM,CACF,IAAI,EACJ,2BAAQ,CAAC,UACL,wCACA,oDACA,oDACA,2CACA,wCACA,4CACA,yCACA,oDACA,oDACA,2CACA,wCACA,2CACA;AACR,sCAAM,CAAC,IAAI,EAAE,4BAAO,CAAC,AAAI,eAAM,CAAC;;;;AAKtC,cAAK,CAAC,aAAa;AACjB,UAAa,SAAS,OAClB,sBACA,kBACA;AAEJ,UAAW;AACX,UAAc;AAEd,gBAAK,CAAC;AACJ,kBAAU,GAAG,IAAI,+BAAqB,CAAC,MAAM;AAC7C,YAAI,GAAG,6BAAoB,CAAC,MAAM,cAAc,OAAO;;AAGzD,eAAI,CACA,kFACA;AACF,YAAI,OAAO,oCAAO,CAAC,UAAU,EAAE,IAAI;AACnC,oCAAM,CAAC,IAAI,MAAM,OAAO,EAAE,yBAAM,CAAC,MAAM,UAAQ,CAAC;AAChD,oCAAM,CAAC,IAAI,IAAI,OAAO,EAAE,yBAAM,CAAC,AAAoB,MAAd,UAAQ,CAAC,OAAO;;AAGvD,eAAI,CAAC,wEACD;AACF,YAAI,OAAO,oCAAO,CAAC,UAAU,EAAE,IAAI,2BAA0B;AAC7D,oCAAM,CAAC,IAAI,MAAM,OAAO,EAAE,yBAAM,CAAC,MAAM,UAAQ,CAAC;AAChD,oCAAM,CAAC,IAAI,IAAI,OAAO,EAAE,yBAAM,CAAC,AAAoB,MAAd,UAAQ,CAAC,OAAO;;;EAG3D","file":"test__unit__transformed_source_file_test.js"}');
  // Exports:
  return {
    unit__transformed_source_file_test: unit__transformed_source_file_test
  };
});

//# sourceMappingURL=test__unit__transformed_source_file_test.js.map
